package Shipment::UPS::WSDL::TrackTypes::ActivityType;
$Shipment::UPS::WSDL::TrackTypes::ActivityType::VERSION = '3.09';
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns { 'http://www.ups.com/XMLSchema/XOLTWS/Track/v2.0' };

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %AlternateTrackingInfo_of :ATTR(:get<AlternateTrackingInfo>);
my %ActivityLocation_of :ATTR(:get<ActivityLocation>);
my %Status_of :ATTR(:get<Status>);
my %Date_of :ATTR(:get<Date>);
my %Time_of :ATTR(:get<Time>);
my %Document_of :ATTR(:get<Document>);
my %AdditionalAttribute_of :ATTR(:get<AdditionalAttribute>);

__PACKAGE__->_factory(
    [ qw(        AlternateTrackingInfo
        ActivityLocation
        Status
        Date
        Time
        Document
        AdditionalAttribute

    ) ],
    {
        'AlternateTrackingInfo' => \%AlternateTrackingInfo_of,
        'ActivityLocation' => \%ActivityLocation_of,
        'Status' => \%Status_of,
        'Date' => \%Date_of,
        'Time' => \%Time_of,
        'Document' => \%Document_of,
        'AdditionalAttribute' => \%AdditionalAttribute_of,
    },
    {
        'AlternateTrackingInfo' => 'Shipment::UPS::WSDL::TrackTypes::AlternateTrackingInfoType',
        'ActivityLocation' => 'Shipment::UPS::WSDL::TrackTypes::ActivityLocationType',
        'Status' => 'Shipment::UPS::WSDL::TrackTypes::StatusType',
        'Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
        'Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
        'Document' => 'Shipment::UPS::WSDL::TrackTypes::DocumentType',
        'AdditionalAttribute' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType',
    },
    {

        'AlternateTrackingInfo' => 'AlternateTrackingInfo',
        'ActivityLocation' => 'ActivityLocation',
        'Status' => 'Status',
        'Date' => 'Date',
        'Time' => 'Time',
        'Document' => 'Document',
        'AdditionalAttribute' => 'AdditionalAttribute',
    }
);

} # end BLOCK







1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Shipment::UPS::WSDL::TrackTypes::ActivityType

=head1 VERSION

version 3.09

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
ActivityType from the namespace http://www.ups.com/XMLSchema/XOLTWS/Track/v2.0.

=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * AlternateTrackingInfo

=item * ActivityLocation

=item * Status

=item * Date

=item * Time

=item * Document

=item * AdditionalAttribute

=back

=head1 NAME

Shipment::UPS::WSDL::TrackTypes::ActivityType

=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # Shipment::UPS::WSDL::TrackTypes::ActivityType
   AlternateTrackingInfo =>  { # Shipment::UPS::WSDL::TrackTypes::AlternateTrackingInfoType
     Type =>  $some_value, # string
     Description =>  $some_value, # string
     Value =>  $some_value, # string
   },
   ActivityLocation =>  { # Shipment::UPS::WSDL::TrackTypes::ActivityLocationType
     Address =>  { # Shipment::UPS::WSDL::TrackTypes::AddressType
       AddressLine =>  $some_value, # string
       City =>  $some_value, # string
       StateProvinceCode =>  $some_value, # string
       PostalCode =>  $some_value, # string
       CountryCode =>  $some_value, # string
     },
     TransportFacility =>  { # Shipment::UPS::WSDL::TrackTypes::TransportFacilityType
       Type =>  $some_value, # string
       Code =>  $some_value, # string
     },
     Code =>  $some_value, # string
     Description =>  $some_value, # string
     SignedForByName =>  $some_value, # string
   },
   Status =>  { # Shipment::UPS::WSDL::TrackTypes::StatusType
     Type =>  $some_value, # string
     Description =>  $some_value, # string
     Code =>  $some_value, # string
   },
   Date =>  $some_value, # string
   Time =>  $some_value, # string
   Document =>  { # Shipment::UPS::WSDL::TrackTypes::DocumentType
     Type =>  { # Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType
       Code =>  $some_value, # string
       Description =>  $some_value, # string
     },
     Content =>  $some_value, # string
     Format =>  { # Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType
       Code =>  $some_value, # string
       Description =>  $some_value, # string
     },
   },
   AdditionalAttribute =>  { # Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType
     Code =>  $some_value, # string
     Description =>  $some_value, # string
     Value =>  $some_value, # string
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=head1 AUTHOR

Andrew Baerg <baergaj@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Andrew Baerg.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
