
package Shipment::UPS::WSDL::TrackTypemaps::TrackService;
$Shipment::UPS::WSDL::TrackTypemaps::TrackService::VERSION = '3.09';
use strict;
use warnings;

our $typemap_1 = {
               'UPSSecurity/UsernameToken/Username' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/AlternateTrackingNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/InquiryNumber/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'UPSSecurity/ServiceAccessToken' => 'Shipment::UPS::WSDL::TrackElements::UPSSecurity::_ServiceAccessToken',
               'TrackResponse/Shipment/COD/Amount/CurrencyCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Address' => 'Shipment::UPS::WSDL::TrackTypes::AddressType',
               'TrackResponse/Shipment/SignedForByName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageServiceOption/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/ServiceCenter/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Document/Format/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Appointment/Made' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'TrackResponse/Shipment/FileNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentWeight/UnitOfMeasurement/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/AdditionalAttribute/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/AdditionalAttribute/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/DeliveryDetail/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Departure' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'TrackResponse/Shipment/AdditionalAttribute' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType',
               'TrackResponse/Shipment/CandidateBookmark' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Document/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Package/Document' => 'Shipment::UPS::WSDL::TrackTypes::DocumentType',
               'TrackResponse/Shipment/Package/Activity/AdditionalAttribute/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Status/Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/InquiryNumber/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/AlternateTrackingInfo/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentAddress/Address/StateProvinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/PrimaryErrorCode' => 'Shipment::UPS::WSDL::TrackTypes::CodeType',
               'TrackResponse/Shipment/DestinationPortDetail/EstimatedArrival' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'TrackResponse/Shipment/ShipmentServiceOption/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/COD/ControlNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentAddress/Address/PostalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Document/Format/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Departure/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Status' => 'Shipment::UPS::WSDL::TrackTypes::StatusType',
               'TrackResponse/Shipment/Package/Activity/AlternateTrackingInfo' => 'Shipment::UPS::WSDL::TrackTypes::AlternateTrackingInfoType',
               'TrackResponse/Shipment/Document/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Response/ResponseStatus' => 'Shipment::UPS::WSDL::TrackTypes::CodeDescriptionType',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation' => 'Shipment::UPS::WSDL::TrackTypes::ActivityLocationType',
               'TrackResponse/Shipment/CurrentStatus/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Appointment' => 'Shipment::UPS::WSDL::TrackTypes::AppointmentType',
               'TrackResponse/Response' => 'Shipment::UPS::WSDL::TrackTypes::ResponseType',
               'TrackResponse/Shipment/Package/PackageAddress' => 'Shipment::UPS::WSDL::TrackTypes::PackageAddressType',
               'TrackResponse/Shipment/COD/Status' => 'Shipment::UPS::WSDL::TrackTypes::CODStatusType',
               'TrackRequest/ShipperAccountInfo/PostalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/COD/Status' => 'Shipment::UPS::WSDL::TrackTypes::CODStatusType',
               'TrackResponse/Shipment/ServiceCenter/Address/PostalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/COD/Status/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentType' => 'Shipment::UPS::WSDL::TrackTypes::RefShipmentType',
               'TrackResponse/Shipment/Activity/Document/Content' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Departure/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/Severity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Document/Content' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/OriginPortDetail' => 'Shipment::UPS::WSDL::TrackTypes::OriginPortDetailType',
               'TrackResponse/Shipment/NumberOfPackagingUnit/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Package/DeliveryDetail/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/COD' => 'Shipment::UPS::WSDL::TrackTypes::CODType',
               'TrackResponse/Shipment/DeliveryDetail/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ReferenceNumber/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DeliveryDetail/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/DeliveryDetail/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentAddress' => 'Shipment::UPS::WSDL::TrackTypes::ShipmentAddressType',
               'TrackResponse/Shipment/ShipmentAddress/Address/CountryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentWeight' => 'Shipment::UPS::WSDL::TrackTypes::WeightType',
               'TrackResponse/Shipment/ServiceCenter/Address/City' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/AlternateTrackingInfo/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipperNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/COD/ControlNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Document/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/NumberOfPackagingUnit/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'TrackResponse/Shipment/Package/Document/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ReferenceNumber/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Address/AddressLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentAddress/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DeliveryDetail/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/COD/Status/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/TrackingNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CargoReady' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'TrackResponse/Response/ResponseStatus/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Response/TransactionReference' => 'Shipment::UPS::WSDL::TrackTypes::TransactionReferenceType',
               'Errors/ErrorDetail/Location/LocationElementName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Document/Format' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Appointment/Requested' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'TrackResponse/Shipment/ShipmentAddress/Address/City' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/AdditionalInformation/Value' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescType',
               'TrackResponse/Shipment/Package/Message/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Address/City' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/ActivityLocation/AddressLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Document/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/COD/Amount/MonetaryValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentAddress/Address' => 'Shipment::UPS::WSDL::TrackTypes::AddressType',
               'Errors/ErrorDetail/PrimaryErrorCode/Digest' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/OriginPortDetail/EstimatedDeparture/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Response/Alert' => 'Shipment::UPS::WSDL::TrackTypes::CodeDescriptionType',
               'TrackResponse/Shipment/Activity/AdditionalAttribute/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageWeight' => 'Shipment::UPS::WSDL::TrackTypes::WeightType',
               'TrackResponse/Shipment/Service/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ServiceCenter' => 'Shipment::UPS::WSDL::TrackTypes::ServiceCenterType',
               'TrackResponse/Shipment/Package/AlternateTrackingInfo/Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/ActivityLocation' => 'Shipment::UPS::WSDL::TrackTypes::AddressType',
               'TrackResponse/Shipment/Activity/ActivityLocation/StateProvinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/AdditionalInformation/Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentServiceOption/AdditionalAttribute' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType',
               'TrackResponse/Shipment/Activity/Trailer' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageServiceOption/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageServiceOption/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/OriginPort' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/InquiryNumber/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/ReferenceNumber/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/InquiryNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Document/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/ShipmentWeight/UnitOfMeasurement' => 'Shipment::UPS::WSDL::TrackTypes::UnitOfMeasurementType',
               'TrackResponse/Shipment/Package/Activity/AdditionalAttribute' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType',
               'TrackResponse/Shipment/Package' => 'Shipment::UPS::WSDL::TrackTypes::PackageType',
               'TrackResponse/Shipment/ServiceCenter/Address/StateProvinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/AdditionalInformation/Value/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentServiceOption/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/ShipmentServiceOption/AdditionalAttribute/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/COD/Amount/MonetaryValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Appointment/Requested/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Service' => 'Shipment::UPS::WSDL::TrackTypes::ServiceType',
               'TrackResponse/Shipment/Activity/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Appointment/Made/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Document' => 'Shipment::UPS::WSDL::TrackTypes::DocumentType',
               'TrackResponse/Shipment/Package/PackageServiceOption/AdditionalAttribute/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/COD/Amount' => 'Shipment::UPS::WSDL::TrackTypes::AmountType',
               'TrackResponse/Shipment/Package/DeliveryDetail/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Document/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity' => 'Shipment::UPS::WSDL::TrackTypes::ActivityType',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Address' => 'Shipment::UPS::WSDL::TrackTypes::AddressType',
               'TrackResponse/Shipment/Package/Activity/Document/Content' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Arrival/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest' => 'Shipment::UPS::WSDL::TrackElements::TrackRequest',
               'TrackResponse/Shipment/CurrentStatus' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Activity/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/Request/TransactionReference/CustomerContext' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Address/City' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Arrival/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/TransportFacility' => 'Shipment::UPS::WSDL::TrackTypes::TransportFacilityType',
               'TrackResponse/Shipment/ShipmentServiceOption/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/AdditionalAttribute/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentAddress/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Document/Format/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail' => 'Shipment::UPS::WSDL::TrackTypes::ErrorDetailType',
               'TrackResponse/Shipment' => 'Shipment::UPS::WSDL::TrackTypes::ShipmentType',
               'TrackResponse/Shipment/AdditionalAttribute/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/BillToName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/ActivityLocation/City' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/CarrierId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ReferenceNumber/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Address/CountryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageServiceOption/AdditionalAttribute' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType',
               'TrackResponse/Shipment/Volume/UnitOfMeasurement/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/MinimumRetrySeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Document/Format/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentServiceOption/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse' => 'Shipment::UPS::WSDL::TrackElements::TrackResponse',
               'TrackResponse/Shipment/Appointment/Made/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Appointment/EndTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Document/Format/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentType/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/SignedForByName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/NumberOfPackagingUnit/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Response/ResponseStatus/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Response/TransactionReference/CustomerContext' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DestinationPortDetail/DestinationPort' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Address/CountryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/AlternateTrackingInfo/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Response/Alert/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Document/Format/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ServiceCenter/Address/AddressLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/COD' => 'Shipment::UPS::WSDL::TrackTypes::CODType',
               'Errors/ErrorDetail/Location/XPathOfElement' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CurrentStatus/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors' => 'Shipment::UPS::WSDL::TrackElements::Errors',
               'TrackResponse/Shipment/Package/ReferenceNumber/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/InquiryNumber' => 'Shipment::UPS::WSDL::TrackTypes::CodeDescriptionValueType',
               'TrackResponse/Shipment/ShipmentAddress/Address/AddressLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CargoReady/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/Request/RequestOption' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Service/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Manifest/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageWeight/Weight' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/TrackingOption' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/COD/Amount' => 'Shipment::UPS::WSDL::TrackTypes::AmountType',
               'TrackResponse/Shipment/Package/Document/Content' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/CandidateBookmark' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Status' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageServiceOption/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/PickupDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Disclaimer' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Address/StateProvinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentServiceOption/AdditionalAttribute/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Manifest' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'UPSSecurity' => 'Shipment::UPS::WSDL::TrackElements::UPSSecurity',
               'Errors/ErrorDetail/AdditionalInformation/Value/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Document/Format/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ServiceCenter/Address/CountryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Volume/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/SubErrorCode' => 'Shipment::UPS::WSDL::TrackTypes::CodeType',
               'TrackResponse/Shipment/Package/AdditionalAttribute' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType',
               'TrackResponse/Shipment/Package/DeliveryDetail/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DeliveryDetail/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'Errors/ErrorDetail/AdditionalInformation' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalInfoType',
               'TrackResponse/Shipment/Package/Message/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentType/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'UPSSecurity/UsernameToken/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/ShipperAccountInfo/CountryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Document/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Message' => 'Shipment::UPS::WSDL::TrackTypes::MessageType',
               'TrackResponse/Shipment/Activity/AdditionalAttribute' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescriptionValueType',
               'TrackResponse/Shipment/Document/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Volume/UnitOfMeasurement' => 'Shipment::UPS::WSDL::TrackTypes::UnitOfMeasurementType',
               'TrackResponse/Shipment/Activity/Document' => 'Shipment::UPS::WSDL::TrackTypes::DocumentType',
               'TrackResponse/Shipment/Package/PackageServiceOption/AdditionalAttribute/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageServiceOption/AdditionalAttribute/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Document/Format' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/TransportFacility/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ReferenceNumber' => 'Shipment::UPS::WSDL::TrackTypes::ShipmentReferenceNumberType',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'TrackResponse/Shipment/Package/Activity/AdditionalAttribute/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/AlternateTrackingInfo' => 'Shipment::UPS::WSDL::TrackTypes::AlternateTrackingInfoType',
               'TrackResponse/Shipment/Appointment/Requested/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/AdditionalAttribute/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/OriginPortDetail/EstimatedDeparture/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/Location/OriginalValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/PrimaryErrorCode/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CargoReady/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Package/Activity/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/ActivityLocation/CountryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'Errors/ErrorDetail/SubErrorCode/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/AlternateTrackingInfo/Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/SubErrorCode/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DescriptionOfGoods' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/OriginPortDetail/EstimatedDeparture' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'Errors/ErrorDetail/SubErrorCode/Digest' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/Request/TransactionReference' => 'Shipment::UPS::WSDL::TrackTypes::TransactionReferenceType',
               'TrackResponse/Shipment/ServiceCenter/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageWeight/UnitOfMeasurement/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DestinationPortDetail/EstimatedArrival/Time' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/NumberOfPackagingUnit' => 'Shipment::UPS::WSDL::TrackTypes::NumberOfPackagingUnitType',
               'TrackResponse/Shipment/CarrierActivityInformation' => 'Shipment::UPS::WSDL::TrackTypes::CarrierActivityInformationType',
               'TrackResponse/Response/Alert/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/AlternateTrackingInfo/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ServiceCenter/Address' => 'Shipment::UPS::WSDL::TrackTypes::AddressType',
               'TrackResponse/Shipment/Document/Type/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Volume' => 'Shipment::UPS::WSDL::TrackTypes::VolumeType',
               'TrackResponse/Shipment/ShipmentWeight/UnitOfMeasurement/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/COD/Amount/CurrencyCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/ActivityLocation/PostalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/Request/TransactionReference/TransactionIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/DeliveryDetail' => 'Shipment::UPS::WSDL::TrackTypes::DeliveryDetailType',
               'TrackResponse/Shipment/Package/PackageWeight/UnitOfMeasurement/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageWeight/UnitOfMeasurement' => 'Shipment::UPS::WSDL::TrackTypes::UnitOfMeasurementType',
               'TrackResponse/Response/TransactionReference/TransactionIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'UPSSecurity/ServiceAccessToken/AccessLicenseNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/AdditionalAttribute/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentServiceOption/AdditionalAttribute/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Document/Format' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Package/Activity/Status/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/Arrival' => 'Shipment::UPS::WSDL::TrackTypes::DateTimeType',
               'TrackResponse/Shipment/Package/Activity/Document/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               #'Fault/detail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               #'Fault/detail' => 'Shipment::UPS::WSDL::TrackElements::Errors',
	       'Fault/detail' => 'Shipment::UPS::WSDL::TrackElements::FaultDetail',
               'Fault/detail/Errors' => 'Shipment::UPS::WSDL::TrackElements::Errors',
               #'Fault/detail/Errors' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail' => 'Shipment::UPS::WSDL::TrackTypes::ErrorDetailType',
               'Fault/detail/Errors/ErrorDetail/Severity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/MinimumRetrySeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/PrimaryErrorCode/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/SubErrorCode/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/SubErrorCode/Digest' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/PrimaryErrorCode/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/PrimaryErrorCode' => 'Shipment::UPS::WSDL::TrackTypes::CodeType',
               'Fault/detail/Errors/ErrorDetail/AdditionalInformation/Value/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/AdditionalInformation' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalInfoType',
               'Fault/detail/Errors/ErrorDetail/SubErrorCode/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/Location/LocationElementName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/AdditionalInformation/Value' => 'Shipment::UPS::WSDL::TrackTypes::AdditionalCodeDescType',
               'Fault/detail/Errors/ErrorDetail/PrimaryErrorCode/Digest' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/AdditionalInformation/Value/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/Location/XPathOfElement' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/Location/OriginalValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/AdditionalInformation/Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/Errors/ErrorDetail/SubErrorCode' => 'Shipment::UPS::WSDL::TrackTypes::CodeType',
               'Fault/detail/Errors/ErrorDetail/Location' => 'Shipment::UPS::WSDL::TrackTypes::LocationType',
               'TrackResponse/Shipment/Package/COD/Status/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageAddress/Address/StateProvinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ServiceCenter/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Package/Activity/Document/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ShipmentServiceOption' => 'Shipment::UPS::WSDL::TrackTypes::ServiceOptionType',
               'TrackRequest/Request' => 'Shipment::UPS::WSDL::TrackTypes::RequestType',
               'TrackResponse/Shipment/Document' => 'Shipment::UPS::WSDL::TrackTypes::DocumentType',
               'TrackResponse/Shipment/Package/Activity/Document/Format' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/ShipmentAddress/Type' => 'Shipment::UPS::WSDL::TrackTypes::CommonCodeDescriptionType',
               'TrackResponse/Shipment/Package/PackageAddress/Address/PostalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity' => 'Shipment::UPS::WSDL::TrackTypes::ShipmentActivityType',
               'TrackResponse/Shipment/Appointment/BeginTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/CarrierActivityInformation/DestinationPort' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Document/Format/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Address/AddressLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/AdditionalAttribute/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/ServiceCenter/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/NumberOfPackagingUnit/Value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/ReferenceNumber' => 'Shipment::UPS::WSDL::TrackTypes::ReferenceNumberType',
               'TrackResponse/Shipment/AdditionalAttribute/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/TransportFacility/Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/COD/Status/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DestinationPortDetail/EstimatedArrival/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/PrimaryErrorCode/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Volume/UnitOfMeasurement/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackRequest/ShipperAccountInfo' => 'Shipment::UPS::WSDL::TrackTypes::ShipperAccountInfoType',
               'TrackResponse/Shipment/ShipmentWeight/Weight' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Activity/AdditionalAttribute/Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DeliveryDetail/Type/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Errors/ErrorDetail/Location' => 'Shipment::UPS::WSDL::TrackTypes::LocationType',
               'TrackResponse/Shipment/OriginPortDetail/OriginPort' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'UPSSecurity/UsernameToken' => 'Shipment::UPS::WSDL::TrackElements::UPSSecurity::_UsernameToken',
               'TrackResponse/Shipment/Manifest/Date' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/PackageServiceOption' => 'Shipment::UPS::WSDL::TrackTypes::ServiceOptionType',
               'TrackResponse/Shipment/Package/Activity/ActivityLocation/Address/PostalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/Package/Activity/Status/Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TrackResponse/Shipment/DeliveryDetail' => 'Shipment::UPS::WSDL::TrackTypes::DeliveryDetailType',
               'TrackResponse/Shipment/DestinationPortDetail' => 'Shipment::UPS::WSDL::TrackTypes::DestinationPortDetailType'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

=pod

=encoding UTF-8

=head1 NAME

Shipment::UPS::WSDL::TrackTypemaps::TrackService

=head1 VERSION

version 3.09

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=head1 NAME

Shipment::UPS::WSDL::TrackTypemaps::TrackService - typemap for TrackService

=head1 AUTHOR

Andrew Baerg <baergaj@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Andrew Baerg.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__END__

__END__


